diff --git a/src/plugins/grass/qgsgrassmodule.cpp b/src/plugins/grass/qgsgrassmodule.cpp
index e50001e..3f15df5 100644
--- a/src/plugins/grass/qgsgrassmodule.cpp
+++ b/src/plugins/grass/qgsgrassmodule.cpp
@@ -353,10 +353,29 @@ QgsGrassModuleStandardOptions::QgsGrassModuleStandardOptions(
     return;
   }
 
+  // convert encoding of interface description by myself because
+  // Qt doesn't recognize most of codepage name "CPxxx" currently
+  QByteArray enc;
+  QByteArray ifDesc = process.readAllStandardOutput();
+  QRegExp reg( "(.+)encoding=\"(.+)\"(.+)" );
+  if ( reg.exactMatch( ifDesc.split( '\n' )[0] ) )
+  {
+    enc = reg.cap( 2 ).toLocal8Bit();
+  }
+
+  QTextCodec *codec = QTextCodec::codecForName( enc );
+  if ( !codec )
+  {
+    // treat codepage name that Qt doesn't recognize as System
+    // default encoding
+    codec = QTextCodec::codecForName( "System" );
+    Q_ASSERT( codec );
+  }
+
   QDomDocument gDoc( "task" );
   QString err;
   int line, column;
-  if ( !gDoc.setContent( &process, false, &err, &line, &column ) )
+  if ( !gDoc.setContent( codec->toUnicode( ifDesc ), false, &err, &line, &column ) )
   {
     QString errmsg = tr( "Cannot read module description (%1):" ).arg( mXName )
                      + tr( "\n%1\nat line %2 column %3" ).arg( err ).arg( line ).arg( column );
